==> apache-ofbiz-18.12.19.zip: apache-ofbiz-18.12.19/framework/base/src/test/java/org/apache/ofbiz/base/collections/MultivaluedMapContextAdapterTests.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *******************************************************************************/
package org.apache.ofbiz.base.collections;

import static org.hamcrest.CoreMatchers.hasItems;
import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertThat;
import static org.junit.Assert.assertTrue;

import java.util.HashMap;

import org.apache.ofbiz.base.util.collections.MultivaluedMapContext;
import org.apache.ofbiz.base.util.collections.MultivaluedMapContextAdapter;
import org.junit.Before;
import org.junit.Test;

public class MultivaluedMapContextAdapterTests {
    private MultivaluedMapContext<String, Integer> adaptee;
    private MultivaluedMapContextAdapter<String, Integer> adapter;

    @Before
    public void setUp() throws Exception {
        adaptee = new MultivaluedMapContext<>();
        adaptee.add("foo", 0);
        adaptee.add("foo", 1);
        adaptee.add("foo", 2);
        adaptee.add("bar", 3);
        adapter = new MultivaluedMapContextAdapter<>(adaptee);
    }

    @Test
    public void containsValueBasic() {
        assertTrue(adapter.containsValue(0));
        assertFalse(adapter.containsValue(1));
        assertFalse(adapter.containsValue(2));
        assertTrue(adapter.containsValue(3));
    }

    @Test
    public void valuesBasic() {
        assertThat(adapter.values(), hasItems(0, 3));
        assertThat(adapter.values().size(), is(2));
    }

    @Test
    public void entrySetBasic() {
        HashMap<String, Integer> expected = new HashMap<>();
        expected.put("foo", 0);
        expected.put("bar", 3);
        assertEquals(expected.entrySet(), adapter.entrySet());
    }
}

==> apache-ofbiz-24.09.04.zip: apache-ofbiz-24.09.04/framework/base/src/test/java/org/apache/ofbiz/base/collections/MultivaluedMapContextAdapterTests.java <==
/*******************************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *******************************************************************************/
package org.apache.ofbiz.base.collections;

import static org.hamcrest.Matchers.containsInAnyOrder;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.Assert.assertTrue;

import java.util.HashMap;

import org.apache.ofbiz.base.util.collections.MultivaluedMapContext;
import org.apache.ofbiz.base.util.collections.MultivaluedMapContextAdapter;
import org.junit.Before;
import org.junit.Test;

public class MultivaluedMapContextAdapterTests {
    private MultivaluedMapContext<String, Integer> adaptee;
    private MultivaluedMapContextAdapter<String, Integer> adapter;

    @Before
    public void setUp() throws Exception {
        adaptee = new MultivaluedMapContext<>();
        adaptee.add("foo", 0);
        adaptee.add("foo", 1);
        adaptee.add("foo", 2);
        adaptee.add("bar", 3);
        adapter = new MultivaluedMapContextAdapter<>(adaptee);
    }

    @Test
    public void containsValueBasic() {
        assertTrue(adapter.containsValue(0));
        assertFalse(adapter.containsValue(1));
        assertFalse(adapter.containsValue(2));
        assertTrue(adapter.containsValue(3));
    }

    @Test
    public void valuesBasic() {
        assertThat(adapter.values(), containsInAnyOrder(0, 3));
    }

    @Test
    public void equalityBasic() {
        HashMap<String, Integer> expected = new HashMap<>();
        expected.put("foo", 0);
        expected.put("bar", 3);
        assertEquals(expected, adapter);
    }
}
